﻿-----------------------------------------------------------------------
-- Locale
-----------------------------------------------------------------------
local L = AceLibrary("AceLocale-2.2"):new("Violation: Damage")

L:RegisterTranslations("enUS", function() return {
	["Damage done"] = true,
	["D"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Damage done"] = "입힌 피해량",
} end)

L:RegisterTranslations("frFR", function() return {
	["Damage done"] = "Dégâts infligés",
	["D"] = "D",
} end)

-----------------------------------------------------------------------
-- Locals
-----------------------------------------------------------------------

local moduleName = "Damage done"

local parser = ParserLib:GetInstance("1.1")
local roster = AceLibrary("Roster-2.1")

-----------------------------------------------------------------------
-- Module declaration
-----------------------------------------------------------------------

local mod = Violation:NewModule(moduleName)
mod.revision = tonumber(("$Revision: 43593 $"):sub(12, -3)) or 1
mod.version = 5
mod.violationCategory = "damage"

-----------------------------------------------------------------------
-- Module initialization
-----------------------------------------------------------------------

function mod:OnModuleEnable()
	parser:RegisterInfoType(self, "hit", "OnParserEvent")
end

function mod:OnModuleDisable()
	parser:UnregisterAllInfoTypes(self)
end

-----------------------------------------------------------------------
-- Module implementation
-----------------------------------------------------------------------

function mod:GetDisplayName() return L["Damage done"] end
function mod:GetShortDisplayName() return L["D"] end

function mod:OnParserEvent( infoType, info, event )
	local source, victim, amount = self:GetSourceVictimAmount(info)
	
	if Violation:IsAnonymousPetEvent(event, info) then
		source = self.playerName
	end

	if not source or amount == 0 or not self:AcceptDataFor(source) then
		return
	end

	-- We ignore split damage from known units to known units.
	-- this includes soullink damage from you to your pet.
	-- thanks rophy for pointing this out.
	if victim and ( victim == playerName or roster:GetUnitIDFromName( victim ) ) then
		return
	end

	self:OnData(source, amount)
end
