﻿-----------------------------------------------------------------------
-- Locale
-----------------------------------------------------------------------
local L = AceLibrary("AceLocale-2.2"):new("Violation: HealingTaken")

L:RegisterTranslations("enUS", function() return {
	["Healing taken"] = true,
	["HT"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Healing taken"] = "받은 치유량",
} end)

L:RegisterTranslations("frFR", function() return {
	["Healing taken"] = "Soins reçus",
	["HT"] = "SR",
} end)

-----------------------------------------------------------------------
-- Locals
-----------------------------------------------------------------------

local moduleName = "Healing taken"

local parser = ParserLib:GetInstance("1.1")
local roster = AceLibrary("Roster-2.1")

-----------------------------------------------------------------------
-- Module declaration
-----------------------------------------------------------------------

local mod = Violation:NewModule(moduleName)
mod.revision = tonumber(("$Revision: 43593 $"):sub(12, -3)) or 1
mod.version = 5
mod.violationCategory = "healing"

-----------------------------------------------------------------------
-- Module initialization
-----------------------------------------------------------------------

function mod:OnModuleEnable()
	parser:RegisterInfoType(self, "heal", self.OnParserEvent)
end

function mod:OnModuleDisable()
	parser:UnregisterAllInfoTypes(self)
end

-----------------------------------------------------------------------
-- Module implementation
-----------------------------------------------------------------------

function mod:GetDisplayName() return L["Healing taken"] end
function mod:GetShortDisplayName() return L["HT"] end

local function getOverheal( unit, amount )
	local overheal = 0
	if unit and UnitExists(unit) then
		local d = UnitHealthMax(unit)-UnitHealth(unit)
		if d < amount then
			overheal = amount - d
		end
	end
	return overheal
end

function mod:OnParserEvent( infoType, info, event )
	local victim, amount = select(2, self:GetSourceVictimAmount(info))
	
	if not victim or amount == 0 or not self:AcceptDataFor( victim ) then
		return
	end

	local victimid = roster:GetUnitIDFromName( victim )
	amount = amount - getOverheal( victimid, amount )
	self:OnData(victim, amount)
end
