﻿-----------------------------------------------------------------------
-- Locale
-----------------------------------------------------------------------
local L = AceLibrary("AceLocale-2.2"):new("Violation: Overhealing")

L:RegisterTranslations("enUS", function() return {
	["Overhealing done"] = true,
	["OH"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Overhealing done"] = "오버힐량",
} end)

L:RegisterTranslations("frFR", function() return {
	["Overhealing done"] = "Soins en excès",
	["OH"] = "SE",
} end)

-----------------------------------------------------------------------
-- Locals
-----------------------------------------------------------------------

local playerName = nil

local parser = ParserLib:GetInstance("1.1")
local roster = AceLibrary("Roster-2.1")

-----------------------------------------------------------------------
-- Locals for  module
-----------------------------------------------------------------------

local moduleName = "Overhealing done"

-----------------------------------------------------------------------
-- Module declaration
-----------------------------------------------------------------------

local mod = Violation:NewModule(moduleName)
mod.revision = tonumber(("$Revision: 43593 $"):sub(12, -3)) or 1
mod.version = 5
mod.violationCategory = "healing"

-----------------------------------------------------------------------
-- Module initialization
-----------------------------------------------------------------------

function mod:OnModuleEnable()
	parser:RegisterInfoType(self, "heal", self.OnParserEvent)
end

function mod:OnModuleDisable()
	parser:UnregisterAllInfoTypes(self)
end

-----------------------------------------------------------------------
-- Module implementation
-----------------------------------------------------------------------

function mod:GetDisplayName() return L["Overhealing done"] end
function mod:GetShortDisplayName() return L["OH"] end
local function getOverheal( unit, amount )
	local overheal = 0
	if unit and UnitExists(unit) then
		local d = UnitHealthMax(unit)-UnitHealth(unit)
		if d < amount then
			overheal = amount - d
		end
	end
	return overheal
end

function mod:OnParserEvent( infoType, info, event )
	local source, victim, amount = self:GetSourceVictimAmount(info)
	
	if not source or not victim or amount == 0 or not self:AcceptDataFor( source ) then
		return
	end

	local victimid = roster:GetUnitIDFromName( victim )
	self:OnData(source, getOverheal( victimid, amount ))
end
