﻿-----------------------------------------------------------------------
-- Locale
-----------------------------------------------------------------------
local L = AceLibrary("AceLocale-2.2"):new("Violation: Critical hit rate")

L:RegisterTranslations("enUS", function() return {
	["Critical hit rate"] = true,
	["Crit%"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Critical hit rate"] = "치명타율",
	["Crit%"] = "치명타",
} end)

L:RegisterTranslations("frFR", function() return {
	["Critical hit rate"] = "Taux de critiques",
	["Crit%"] = "Crit%",
} end)

-----------------------------------------------------------------------
-- Locals
-----------------------------------------------------------------------

local moduleName = "Critical hit rate"
local hitCount = {}
local critCount = {}

local roster = AceLibrary("Roster-2.1")
local parser = ParserLib:GetInstance("1.1")

-----------------------------------------------------------------------
-- Module declaration
-----------------------------------------------------------------------

local mod = Violation:NewModule(moduleName)
mod.revision = tonumber(("$Revision: 43593 $"):sub(12, -3)) or 1
mod.version = 5
mod.dataFormatter = "%5.1f%%"
mod.hidePercentage = true
mod.violationCategory = "other"

-----------------------------------------------------------------------
-- Module initialization
-----------------------------------------------------------------------

function mod:OnModuleEnable()
	parser:RegisterInfoType( self, "hit", "OnParserEvent" )
end

function mod:OnModuleDisable()
	parser:UnregisterAllInfoTypes( self )
end

function mod:OnReset()
	if type(hitCount) == "table" then
		hitCount = mod:del(hitCount)
	end
	hitCount = mod:new()
	
	if type(critCount) == "table" then
		critCount = mod:del(critCount)
	end
	critCount = mod:new()
end

-----------------------------------------------------------------------
-- Module implementation
-----------------------------------------------------------------------

function mod:GetDisplayName() return L["Critical hit rate"] end
function mod:GetShortDisplayName() return L["Crit%"] end

function mod:OnData(name, input, remote)
	if name and input then
		if not remote then
			self.broadcast[name] = input
		end
		self.dirty = (input ~= (self.data[name] or 0))
		self.data[name] = input
	end
end

function mod:OnParserEvent( infoType, info, event )
	local name, victim, amount = self:GetSourceVictimAmount(info)

	if not name or amount == 0 or info.isDOT or not self:AcceptDataFor(name) then 
		return
	end
	
	-- We ignore split damage from known units to known units.
	-- this includes soullink damage from you to your pet.
	-- thanks rophy for pointing this out.
	if info.isSplit and victim then
		if victim == self.playerName or roster:GetUnitIDFromName( victim ) then
			return
		end
	end
	
	hitCount[name] = (hitCount[name] or 0) + 1
	if info.isCrit then
		critCount[name] = (critCount[name] or 0) + 1
	end
	
	self:OnData(name, math.floor(100.0 * (critCount[name] or 0) / (hitCount[name] or 1)))
end
